@@ -60,21 +60,21 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
                 "Choose your Position Size for {} per trade in %: ".format(symbol))
             pos_size = check_pos_size(pos_size)
             symbol_settings.append(Symbol(name=symbol, position_size=pos_size))
-        return make_pickle_file(settings_path, setting_name, token, api_key, api_secret, symbol_settings)
+        return make_pickle_file(setting_path, setting_name, token, api_key, api_secret, symbol_settings)
 
 
 def position_symbol_sizes(symbols):
     output = ''
     for symbol in symbols:
         output += '\n\t{} Position Size: {} %\n\n'.format(
-            symbol['name'], symbol['position_size'])
+            symbol.name, symbol.position_size)
     return output
 
 
 def check_settings(settings, broker):
     while True:
         qr = input("Start Algo Trader Bot with"
-                   "\n\tBroker: " + broker +
+                   "\n\tBroker: " + broker.replace('_', ' ').title() +
                    "\n\tToken: {}..."
                    "\n\tAPI ID: {}"
                    "\n\tAPI Secret: ...{}"
